@@ -26,7 +26,7 @@ local({
         x.entry<-tkentry(tt, textvariable=Xlab)
         int.entry<-tkentry(tt, textvariable=Int)
         nseq.entry<-tkentry(tt, textvariable=Ne)
-        
+        col.entry<-tkentry(tt, textvariable=Col)
         
   x.lab<- tclVar("Mean")              
 	done <- tclVar(0)
@@ -44,10 +44,11 @@ local({
             tclvalue(Stat4)<-"NULL"
             tclvalue(Func)<-"NULL"
             tclvalue(Rep)<-""
-            tclvalue(Xlab)<-"Mean"
+            tclvalue(Xlab)<-"expression(Mean)"
             tclvalue(Int)<-"0.1"
             tclvalue(fixn)<-"1"
             tclvalue(show.SE)<-"0"
+            tclvalue(Col)<-"rainbow"
             tclvalue(Ne)<-"seq(1,30)"
             
         }
@@ -65,26 +66,28 @@ local({
             stat3 <-parse(text=tclvalue(Stat3))[[1]]
             stat4 <-parse(text=tclvalue(Stat4))[[1]]
             R <-tclvalue(Rep)
-            x<-tclvalue(Xlab)
+            x<-parse(text=tclvalue(Xlab))[[1]]
             func<-parse(text=tclvalue(Func))[[1]]
             f <- as.logical(tclObj(fixn))
             se <- as.logical(tclObj(show.SE))
             interval<-tclvalue(Int)
+            col.anim <-tclvalue(Col)
             n.seq<-parse(text=tclvalue(Ne))[[1]]
             
-           substitute(samp.dist(parent=parent,parent2=parent2,s.size=as.numeric(s.size),s.size2=as.numeric(s.size2),stat=stat,stat2=stat2,stat3=stat3,stat4=stat4, func=func,R=as.numeric(R),fix.n=f,xlab=x,interval=as.numeric(interval),n.seq=n.seq,show.SE=se))
+           substitute(samp.dist(parent=parent,parent2=parent2,s.size=as.numeric(s.size),s.size2=as.numeric(s.size2),stat=stat,stat2=stat2,stat3=stat3,stat4=stat4, func=func,R=as.numeric(R),fix.n=f,xlab=x,interval=as.numeric(interval),n.seq=n.seq,show.SE=se,col.anim=col.anim))
         }
         n.cbut <- tkcheckbutton(tt, text="Fix n", variable=fixn)
         se.cbut <- tkcheckbutton(tt, text="Show SE", variable=show.SE)
-        tkgrid(tklabel(tt,text="Sampling distributions"),columnspan=4)
+        tkgrid(tklabel(tt,text="Sampling distribution animations"),columnspan=4)
         tkgrid(tklabel(tt,text=""))
-        tkgrid(tklabel(tt,text="Parent 1"), parent.entry1,tklabel(tt,text="Parent 2"), parent.entry2)
-        tkgrid(tklabel(tt,text="Samp size 1"), s.size1.entry,tklabel(tt,text="Samp size 2"), s.size2.entry)
-        tkgrid(tklabel(tt,text="Stat"), stat.entry1,tklabel(tt,text="Stat 2"), stat.entry2)
+        tkgrid(tklabel(tt,text="Parent 1",font=c("Helvetica","9","bold"),foreground="red"), parent.entry1,tklabel(tt,text="Parent 2"), parent.entry2)
+        tkgrid(tklabel(tt,text="Samp size 1",font=c("Helvetica","9","bold"),foreground="red"), s.size1.entry,tklabel(tt,text="Samp size 2"), s.size2.entry)
+        tkgrid(tklabel(tt,text="Stat",font=c("Helvetica","9","bold"),foreground="red"), stat.entry1,tklabel(tt,text="Stat 2"), stat.entry2)
         tkgrid(tklabel(tt,text="Stat 3"), stat.entry3, tklabel(tt,text="Stat 4"), stat.entry4)
         tkgrid(tklabel(tt,text=""))
         tkgrid(tklabel(tt,text=""),tklabel(tt,text="Iterations"), R.entry)
         tkgrid(tklabel(tt,text=""),tklabel(tt,text="Function"), func.entry)
+        tkgrid(tklabel(tt,text=""),tklabel(tt,text="Anim. color"), col.entry)
         tkgrid(tklabel(tt,text=""),tklabel(tt,text="Anim. interval"), int.entry)
         tkgrid(tklabel(tt,text=""),tklabel(tt,text="X-axis label"), x.entry)
         tkgrid(tklabel(tt,text=""))
@@ -116,8 +119,9 @@ local({
       Func<-tclVar("NULL")
       Rep<-tclVar("1000")
       Ne<-tclVar("seq(1,30)")
-      Xlab<- tclVar("Mean")
-      Int<-tclVar("0.1")
+      Xlab<- tclVar("expression(Mean)")
+      Col<- tclVar("rainbow")
+      Int<-tclVar("0.01")
       dialog.sd()
    
 })
